@@ -264,12 +264,9 @@ device_type_is_present (InfoIdentifyFunc info_func,
                         continue;
 
                 retval = (device_func) (device);
-                if (retval) {
-                        XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), device);
+                xdevice_close (device);
+                if (retval)
                         break;
-                }
-
-                XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), device);
         }
         XFreeDeviceList (device_info);
 
@@ -610,3 +607,11 @@ xdevice_get_wacom_tool_type (int deviceid)
 
         return ret;
 }
+
+void
+xdevice_close (XDevice *xdevice)
+{
+    gdk_error_trap_push ();
+    XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
+    gdk_error_trap_pop_ignored();
+}
