@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -30,8 +29,12 @@
 #include <geocode-glib/geocode-glib.h>
 #include <polkit/polkit.h>
 
+#define DESKTOP_ID "gnome-datetime-panel"
 #define SET_TIMEZONE_PERMISSION "org.freedesktop.timedate1.set-timezone"
 
+/* Defines from geoclue private header src/public-api/gclue-enums.h */
+#define GCLUE_ACCURACY_LEVEL_CITY 4
+
 enum {
         TIMEZONE_CHANGED,
         LAST_SIGNAL
@@ -339,8 +342,11 @@ on_client_proxy_ready (GObject      *source_object,
                 return;
         }
 
+        geoclue_client_set_desktop_id (priv->geoclue_client, DESKTOP_ID);
         geoclue_client_set_distance_threshold (priv->geoclue_client,
                                                GEOCODE_LOCATION_ACCURACY_CITY);
+        geoclue_client_set_requested_accuracy_level (priv->geoclue_client,
+                                                     GCLUE_ACCURACY_LEVEL_CITY);
 
         g_signal_connect (priv->geoclue_client, "location-updated",
                           G_CALLBACK (on_location_updated), self);
