@@ -268,7 +268,7 @@ wacom_set_property (GsdWacomDevice *device,
 
 	xdev = open_device (device);
 	device_set_property (xdev, gsd_wacom_device_get_tool_name (device), property);
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdev);
+	xdevice_close (xdev);
 }
 
 static void
@@ -367,7 +367,7 @@ set_absolute (GsdWacomDevice  *device,
 	if (gdk_error_trap_pop ())
 		g_error ("Failed to set mode \"%s\" for \"%s\".",
 			 is_absolute ? "Absolute" : "Relative", gsd_wacom_device_get_tool_name (device));
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdev);
+	xdevice_close (xdev);
 }
 
 static void
@@ -518,7 +518,7 @@ set_device_buttonmap (GsdWacomDevice *device,
 
 	g_free (map);
 
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdev);
+	xdevice_close (xdev);
 }
 
 static void
@@ -747,7 +747,7 @@ reset_pad_buttons (GsdWacomDevice *device)
 	reset_touch_buttons (xdev, def_touchstrip_buttons, "Wacom Strip Buttons");
 	gdk_error_trap_pop_ignored ();
 
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdev);
+	xdevice_close (xdev);
 
 	update_pad_leds (device);
 }
